@@ -535,8 +535,7 @@ public class ZipFile {
   }
 
   /**
-   * Returns the list of file headers in the zip file. Throws an exception if the
-   * zip file does not exist
+   * Returns the list of file headers in the zip file. Returns an empty list if the zip file does not exist.
    *
    * @return list of file headers
    * @throws ZipException
@@ -760,7 +759,7 @@ public class ZipFile {
    * @return ZipInputStream
    * @throws ZipException
    */
-  public ZipInputStream getInputStream(FileHeader fileHeader) throws ZipException {
+  public ZipInputStream getInputStream(FileHeader fileHeader) throws IOException {
     if (fileHeader == null) {
       throw new ZipException("FileHeader is null, cannot get InputStream");
     }
@@ -809,6 +808,14 @@ public class ZipFile {
     return FileUtils.getSplitZipFiles(zipModel);
   }
 
+  /**
+   * Sets a password to be used for the zip file. Will override if a password supplied via ZipFile constructor
+   * @param password - char array of the password to be used
+   */
+  public void setPassword(char[] password) {
+    this.password = password;
+  }
+
   /**
    * Reads the zip header information for this zip file. If the zip file
    * does not exist, then this method throws an exception.<br><br>
