@@ -23,6 +23,7 @@ import java.util.List;
 import java.util.stream.Collectors;
 
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.fail;
 
 public class MiscZipFileIT extends AbstractIT {
 
@@ -384,10 +385,47 @@ public class MiscZipFileIT extends AbstractIT {
     File newFile = temporaryFolder.newFile("NEW_FILE_NAME.ZIP");
     String oldFile = generatedZipFile.getPath();
 
+    if(TestUtils.isWindows())
+    {
+      newFile.delete();
+    }
+
     assertThat(generatedZipFile.renameTo(newFile)).isTrue();
     assertThat(new File(oldFile)).doesNotExist();
   }
 
+  @Test
+  public void testZipSlipFix() throws Exception {
+    ZipParameters zipParameters = new ZipParameters();
+    zipParameters.setFileNameInZip("../../bad.txt");
+
+    ZipFile zip = new ZipFile(generatedZipFile);
+    zip.addFile(TestUtils.getTestFileFromResources("sample_text1.txt"), zipParameters);
+
+    try {
+      zip.extractAll(outputFolder.getAbsolutePath());
+      fail("zip4j is vulnerable for slip zip");
+    } catch (ZipException e) {
+      assertThat(e).hasMessageStartingWith("illegal file name that breaks out of the target directory: ");
+    }
+  }
+
+  @Test
+  public void testExtractFileDeletesOutputFileWhenWrongPassword() throws IOException {
+    ZipParameters zipParameters = createZipParameters(EncryptionMethod.ZIP_STANDARD, AesKeyStrength.KEY_STRENGTH_256);
+    ZipFile zipFile = new ZipFile(generatedZipFile, PASSWORD);
+    zipFile.addFile(TestUtils.getTestFileFromResources("sample_text1.txt"), zipParameters);
+
+    try {
+      zipFile = new ZipFile(generatedZipFile, "WRONG_PASSWORD".toCharArray());
+      zipFile.extractAll(outputFolder.getCanonicalPath());
+      fail("Should throw an exception");
+    } catch (ZipException e) {
+      assertThat(new File(outputFolder.getCanonicalPath() + "sample_text1.txt")).doesNotExist();
+      assertThat(e.getType()).isEqualTo(ZipException.Type.WRONG_PASSWORD);
+    }
+  }
+
   private void verifyInputStream(InputStream inputStream, File fileToCompareAgainst) throws IOException {
     File outputFile = temporaryFolder.newFile();
     try (OutputStream outputStream = new FileOutputStream(outputFile)) {
